@@ -1,7 +1,7 @@
 """
 Type annotations for discovery service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_discovery/type_defs.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_discovery/type_defs/)
 
 Usage::
 
@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Dict, List, Sequence, Union
 
 from .literals import (
     AgentStatusType,
@@ -27,11 +27,11 @@ from .literals import (
     orderStringType,
 )
 
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import Literal
 else:
     from typing_extensions import Literal
-if sys.version_info >= (3, 8):
+if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
     from typing_extensions import TypedDict
@@ -39,65 +39,73 @@ else:
 
 __all__ = (
     "AgentConfigurationStatusTypeDef",
-    "AgentInfoTypeDef",
     "AgentNetworkInfoTypeDef",
     "AssociateConfigurationItemsToApplicationRequestRequestTypeDef",
     "BatchDeleteImportDataErrorTypeDef",
     "BatchDeleteImportDataRequestRequestTypeDef",
-    "BatchDeleteImportDataResponseTypeDef",
+    "ResponseMetadataTypeDef",
     "ConfigurationTagTypeDef",
     "ContinuousExportDescriptionTypeDef",
     "CreateApplicationRequestRequestTypeDef",
-    "CreateApplicationResponseTypeDef",
-    "CreateTagsRequestRequestTypeDef",
+    "TagTypeDef",
     "CustomerAgentInfoTypeDef",
+    "CustomerAgentlessCollectorInfoTypeDef",
     "CustomerConnectorInfoTypeDef",
+    "CustomerMeCollectorInfoTypeDef",
     "DeleteApplicationsRequestRequestTypeDef",
-    "DeleteTagsRequestRequestTypeDef",
-    "DescribeAgentsRequestRequestTypeDef",
-    "DescribeAgentsResponseTypeDef",
-    "DescribeConfigurationsRequestRequestTypeDef",
-    "DescribeConfigurationsResponseTypeDef",
-    "DescribeContinuousExportsRequestRequestTypeDef",
-    "DescribeContinuousExportsResponseTypeDef",
-    "DescribeExportConfigurationsRequestRequestTypeDef",
-    "DescribeExportConfigurationsResponseTypeDef",
-    "DescribeExportTasksRequestRequestTypeDef",
-    "DescribeExportTasksResponseTypeDef",
-    "DescribeImportTasksRequestRequestTypeDef",
-    "DescribeImportTasksResponseTypeDef",
-    "DescribeTagsRequestRequestTypeDef",
-    "DescribeTagsResponseTypeDef",
-    "DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef",
-    "ExportConfigurationsResponseTypeDef",
-    "ExportFilterTypeDef",
-    "ExportInfoTypeDef",
     "FilterTypeDef",
-    "GetDiscoverySummaryResponseTypeDef",
+    "PaginatorConfigTypeDef",
+    "DescribeConfigurationsRequestRequestTypeDef",
+    "DescribeContinuousExportsRequestRequestTypeDef",
+    "DescribeExportConfigurationsRequestRequestTypeDef",
+    "ExportInfoTypeDef",
+    "ExportFilterTypeDef",
     "ImportTaskFilterTypeDef",
     "ImportTaskTypeDef",
-    "ListConfigurationsRequestRequestTypeDef",
-    "ListConfigurationsResponseTypeDef",
-    "ListServerNeighborsRequestRequestTypeDef",
-    "ListServerNeighborsResponseTypeDef",
-    "NeighborConnectionDetailTypeDef",
-    "OrderByElementTypeDef",
-    "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "StartContinuousExportResponseTypeDef",
-    "StartDataCollectionByAgentIdsRequestRequestTypeDef",
-    "StartDataCollectionByAgentIdsResponseTypeDef",
-    "StartExportTaskRequestRequestTypeDef",
-    "StartExportTaskResponseTypeDef",
-    "StartImportTaskRequestRequestTypeDef",
-    "StartImportTaskResponseTypeDef",
-    "StopContinuousExportRequestRequestTypeDef",
-    "StopContinuousExportResponseTypeDef",
-    "StopDataCollectionByAgentIdsRequestRequestTypeDef",
-    "StopDataCollectionByAgentIdsResponseTypeDef",
     "TagFilterTypeDef",
-    "TagTypeDef",
+    "DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef",
+    "OrderByElementTypeDef",
+    "ListServerNeighborsRequestRequestTypeDef",
+    "NeighborConnectionDetailTypeDef",
+    "StartDataCollectionByAgentIdsRequestRequestTypeDef",
+    "StartImportTaskRequestRequestTypeDef",
+    "StopContinuousExportRequestRequestTypeDef",
+    "StopDataCollectionByAgentIdsRequestRequestTypeDef",
     "UpdateApplicationRequestRequestTypeDef",
+    "AgentInfoTypeDef",
+    "BatchDeleteImportDataResponseTypeDef",
+    "CreateApplicationResponseTypeDef",
+    "DescribeConfigurationsResponseTypeDef",
+    "ExportConfigurationsResponseTypeDef",
+    "ListConfigurationsResponseTypeDef",
+    "StartContinuousExportResponseTypeDef",
+    "StartDataCollectionByAgentIdsResponseTypeDef",
+    "StartExportTaskResponseTypeDef",
+    "StopContinuousExportResponseTypeDef",
+    "StopDataCollectionByAgentIdsResponseTypeDef",
+    "DescribeTagsResponseTypeDef",
+    "DescribeContinuousExportsResponseTypeDef",
+    "CreateTagsRequestRequestTypeDef",
+    "DeleteTagsRequestRequestTypeDef",
+    "GetDiscoverySummaryResponseTypeDef",
+    "DescribeAgentsRequestRequestTypeDef",
+    "DescribeAgentsRequestDescribeAgentsPaginateTypeDef",
+    "DescribeContinuousExportsRequestDescribeContinuousExportsPaginateTypeDef",
+    "DescribeExportConfigurationsRequestDescribeExportConfigurationsPaginateTypeDef",
+    "DescribeExportConfigurationsResponseTypeDef",
+    "DescribeExportTasksResponseTypeDef",
+    "DescribeExportTasksRequestDescribeExportTasksPaginateTypeDef",
+    "DescribeExportTasksRequestRequestTypeDef",
+    "StartExportTaskRequestRequestTypeDef",
+    "DescribeImportTasksRequestRequestTypeDef",
+    "DescribeImportTasksResponseTypeDef",
+    "StartImportTaskResponseTypeDef",
+    "DescribeTagsRequestDescribeTagsPaginateTypeDef",
+    "DescribeTagsRequestRequestTypeDef",
+    "ListConfigurationsRequestListConfigurationsPaginateTypeDef",
+    "ListConfigurationsRequestRequestTypeDef",
+    "ListServerNeighborsResponseTypeDef",
+    "DescribeAgentsResponseTypeDef",
 )
 
 AgentConfigurationStatusTypeDef = TypedDict(
@@ -110,23 +118,6 @@ AgentConfigurationStatusTypeDef = TypedDict(
     total=False,
 )
 
-AgentInfoTypeDef = TypedDict(
-    "AgentInfoTypeDef",
-    {
-        "agentId": str,
-        "hostName": str,
-        "agentNetworkInfoList": List["AgentNetworkInfoTypeDef"],
-        "connectorId": str,
-        "version": str,
-        "health": AgentStatusType,
-        "lastHealthPingTime": str,
-        "collectionStatus": str,
-        "agentType": str,
-        "registeredTime": str,
-    },
-    total=False,
-)
-
 AgentNetworkInfoTypeDef = TypedDict(
     "AgentNetworkInfoTypeDef",
     {
@@ -140,7 +131,7 @@ AssociateConfigurationItemsToApplicationRequestRequestTypeDef = TypedDict(
     "AssociateConfigurationItemsToApplicationRequestRequestTypeDef",
     {
         "applicationConfigurationId": str,
-        "configurationIds": List[str],
+        "configurationIds": Sequence[str],
     },
 )
 
@@ -157,15 +148,18 @@ BatchDeleteImportDataErrorTypeDef = TypedDict(
 BatchDeleteImportDataRequestRequestTypeDef = TypedDict(
     "BatchDeleteImportDataRequestRequestTypeDef",
     {
-        "importTaskIds": List[str],
+        "importTaskIds": Sequence[str],
     },
 )
 
-BatchDeleteImportDataResponseTypeDef = TypedDict(
-    "BatchDeleteImportDataResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "errors": List["BatchDeleteImportDataErrorTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -217,19 +211,11 @@ class CreateApplicationRequestRequestTypeDef(
     pass
 
 
-CreateApplicationResponseTypeDef = TypedDict(
-    "CreateApplicationResponseTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "configurationId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-CreateTagsRequestRequestTypeDef = TypedDict(
-    "CreateTagsRequestRequestTypeDef",
-    {
-        "configurationIds": List[str],
-        "tags": List["TagTypeDef"],
+        "key": str,
+        "value": str,
     },
 )
 
@@ -246,6 +232,19 @@ CustomerAgentInfoTypeDef = TypedDict(
     },
 )
 
+CustomerAgentlessCollectorInfoTypeDef = TypedDict(
+    "CustomerAgentlessCollectorInfoTypeDef",
+    {
+        "activeAgentlessCollectors": int,
+        "healthyAgentlessCollectors": int,
+        "denyListedAgentlessCollectors": int,
+        "shutdownAgentlessCollectors": int,
+        "unhealthyAgentlessCollectors": int,
+        "totalAgentlessCollectors": int,
+        "unknownAgentlessCollectors": int,
+    },
+)
+
 CustomerConnectorInfoTypeDef = TypedDict(
     "CustomerConnectorInfoTypeDef",
     {
@@ -259,190 +258,72 @@ CustomerConnectorInfoTypeDef = TypedDict(
     },
 )
 
+CustomerMeCollectorInfoTypeDef = TypedDict(
+    "CustomerMeCollectorInfoTypeDef",
+    {
+        "activeMeCollectors": int,
+        "healthyMeCollectors": int,
+        "denyListedMeCollectors": int,
+        "shutdownMeCollectors": int,
+        "unhealthyMeCollectors": int,
+        "totalMeCollectors": int,
+        "unknownMeCollectors": int,
+    },
+)
+
 DeleteApplicationsRequestRequestTypeDef = TypedDict(
     "DeleteApplicationsRequestRequestTypeDef",
     {
-        "configurationIds": List[str],
+        "configurationIds": Sequence[str],
     },
 )
 
-_RequiredDeleteTagsRequestRequestTypeDef = TypedDict(
-    "_RequiredDeleteTagsRequestRequestTypeDef",
+FilterTypeDef = TypedDict(
+    "FilterTypeDef",
     {
-        "configurationIds": List[str],
+        "name": str,
+        "values": Sequence[str],
+        "condition": str,
     },
 )
-_OptionalDeleteTagsRequestRequestTypeDef = TypedDict(
-    "_OptionalDeleteTagsRequestRequestTypeDef",
+
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "tags": List["TagTypeDef"],
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class DeleteTagsRequestRequestTypeDef(
-    _RequiredDeleteTagsRequestRequestTypeDef, _OptionalDeleteTagsRequestRequestTypeDef
-):
-    pass
-
-
-DescribeAgentsRequestRequestTypeDef = TypedDict(
-    "DescribeAgentsRequestRequestTypeDef",
-    {
-        "agentIds": List[str],
-        "filters": List["FilterTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-DescribeAgentsResponseTypeDef = TypedDict(
-    "DescribeAgentsResponseTypeDef",
-    {
-        "agentsInfo": List["AgentInfoTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeConfigurationsRequestRequestTypeDef = TypedDict(
     "DescribeConfigurationsRequestRequestTypeDef",
     {
-        "configurationIds": List[str],
-    },
-)
-
-DescribeConfigurationsResponseTypeDef = TypedDict(
-    "DescribeConfigurationsResponseTypeDef",
-    {
-        "configurations": List[Dict[str, str]],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "configurationIds": Sequence[str],
     },
 )
 
 DescribeContinuousExportsRequestRequestTypeDef = TypedDict(
     "DescribeContinuousExportsRequestRequestTypeDef",
     {
-        "exportIds": List[str],
+        "exportIds": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
-DescribeContinuousExportsResponseTypeDef = TypedDict(
-    "DescribeContinuousExportsResponseTypeDef",
-    {
-        "descriptions": List["ContinuousExportDescriptionTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeExportConfigurationsRequestRequestTypeDef = TypedDict(
     "DescribeExportConfigurationsRequestRequestTypeDef",
     {
-        "exportIds": List[str],
+        "exportIds": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
     total=False,
 )
 
-DescribeExportConfigurationsResponseTypeDef = TypedDict(
-    "DescribeExportConfigurationsResponseTypeDef",
-    {
-        "exportsInfo": List["ExportInfoTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeExportTasksRequestRequestTypeDef = TypedDict(
-    "DescribeExportTasksRequestRequestTypeDef",
-    {
-        "exportIds": List[str],
-        "filters": List["ExportFilterTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-DescribeExportTasksResponseTypeDef = TypedDict(
-    "DescribeExportTasksResponseTypeDef",
-    {
-        "exportsInfo": List["ExportInfoTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeImportTasksRequestRequestTypeDef = TypedDict(
-    "DescribeImportTasksRequestRequestTypeDef",
-    {
-        "filters": List["ImportTaskFilterTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-DescribeImportTasksResponseTypeDef = TypedDict(
-    "DescribeImportTasksResponseTypeDef",
-    {
-        "nextToken": str,
-        "tasks": List["ImportTaskTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeTagsRequestRequestTypeDef = TypedDict(
-    "DescribeTagsRequestRequestTypeDef",
-    {
-        "filters": List["TagFilterTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-DescribeTagsResponseTypeDef = TypedDict(
-    "DescribeTagsResponseTypeDef",
-    {
-        "tags": List["ConfigurationTagTypeDef"],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef = TypedDict(
-    "DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef",
-    {
-        "applicationConfigurationId": str,
-        "configurationIds": List[str],
-    },
-)
-
-ExportConfigurationsResponseTypeDef = TypedDict(
-    "ExportConfigurationsResponseTypeDef",
-    {
-        "exportId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ExportFilterTypeDef = TypedDict(
-    "ExportFilterTypeDef",
-    {
-        "name": str,
-        "values": List[str],
-        "condition": str,
-    },
-)
-
 _RequiredExportInfoTypeDef = TypedDict(
     "_RequiredExportInfoTypeDef",
     {
@@ -468,33 +349,20 @@ class ExportInfoTypeDef(_RequiredExportInfoTypeDef, _OptionalExportInfoTypeDef):
     pass
 
 
-FilterTypeDef = TypedDict(
-    "FilterTypeDef",
+ExportFilterTypeDef = TypedDict(
+    "ExportFilterTypeDef",
     {
         "name": str,
-        "values": List[str],
+        "values": Sequence[str],
         "condition": str,
     },
 )
 
-GetDiscoverySummaryResponseTypeDef = TypedDict(
-    "GetDiscoverySummaryResponseTypeDef",
-    {
-        "servers": int,
-        "applications": int,
-        "serversMappedToApplications": int,
-        "serversMappedtoTags": int,
-        "agentSummary": "CustomerAgentInfoTypeDef",
-        "connectorSummary": "CustomerConnectorInfoTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ImportTaskFilterTypeDef = TypedDict(
     "ImportTaskFilterTypeDef",
     {
         "name": ImportTaskFilterNameType,
-        "values": List[str],
+        "values": Sequence[str],
     },
     total=False,
 )
@@ -519,40 +387,41 @@ ImportTaskTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredListConfigurationsRequestRequestTypeDef = TypedDict(
-    "_RequiredListConfigurationsRequestRequestTypeDef",
+TagFilterTypeDef = TypedDict(
+    "TagFilterTypeDef",
     {
-        "configurationType": ConfigurationItemTypeType,
+        "name": str,
+        "values": Sequence[str],
     },
 )
-_OptionalListConfigurationsRequestRequestTypeDef = TypedDict(
-    "_OptionalListConfigurationsRequestRequestTypeDef",
+
+DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef = TypedDict(
+    "DisassociateConfigurationItemsFromApplicationRequestRequestTypeDef",
     {
-        "filters": List["FilterTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-        "orderBy": List["OrderByElementTypeDef"],
+        "applicationConfigurationId": str,
+        "configurationIds": Sequence[str],
+    },
+)
+
+_RequiredOrderByElementTypeDef = TypedDict(
+    "_RequiredOrderByElementTypeDef",
+    {
+        "fieldName": str,
+    },
+)
+_OptionalOrderByElementTypeDef = TypedDict(
+    "_OptionalOrderByElementTypeDef",
+    {
+        "sortOrder": orderStringType,
     },
     total=False,
 )
 
 
-class ListConfigurationsRequestRequestTypeDef(
-    _RequiredListConfigurationsRequestRequestTypeDef,
-    _OptionalListConfigurationsRequestRequestTypeDef,
-):
+class OrderByElementTypeDef(_RequiredOrderByElementTypeDef, _OptionalOrderByElementTypeDef):
     pass
 
 
-ListConfigurationsResponseTypeDef = TypedDict(
-    "ListConfigurationsResponseTypeDef",
-    {
-        "configurations": List[Dict[str, str]],
-        "nextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListServerNeighborsRequestRequestTypeDef = TypedDict(
     "_RequiredListServerNeighborsRequestRequestTypeDef",
     {
@@ -563,7 +432,7 @@ _OptionalListServerNeighborsRequestRequestTypeDef = TypedDict(
     "_OptionalListServerNeighborsRequestRequestTypeDef",
     {
         "portInformationNeeded": bool,
-        "neighborConfigurationIds": List[str],
+        "neighborConfigurationIds": Sequence[str],
         "maxResults": int,
         "nextToken": str,
     },
@@ -578,16 +447,6 @@ class ListServerNeighborsRequestRequestTypeDef(
     pass
 
 
-ListServerNeighborsResponseTypeDef = TypedDict(
-    "ListServerNeighborsResponseTypeDef",
-    {
-        "neighbors": List["NeighborConnectionDetailTypeDef"],
-        "nextToken": str,
-        "knownDependencyCount": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredNeighborConnectionDetailTypeDef = TypedDict(
     "_RequiredNeighborConnectionDetailTypeDef",
     {
@@ -612,89 +471,10 @@ class NeighborConnectionDetailTypeDef(
     pass
 
 
-_RequiredOrderByElementTypeDef = TypedDict(
-    "_RequiredOrderByElementTypeDef",
-    {
-        "fieldName": str,
-    },
-)
-_OptionalOrderByElementTypeDef = TypedDict(
-    "_OptionalOrderByElementTypeDef",
-    {
-        "sortOrder": orderStringType,
-    },
-    total=False,
-)
-
-
-class OrderByElementTypeDef(_RequiredOrderByElementTypeDef, _OptionalOrderByElementTypeDef):
-    pass
-
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, Any],
-        "RetryAttempts": int,
-    },
-)
-
-StartContinuousExportResponseTypeDef = TypedDict(
-    "StartContinuousExportResponseTypeDef",
-    {
-        "exportId": str,
-        "s3Bucket": str,
-        "startTime": datetime,
-        "dataSource": Literal["AGENT"],
-        "schemaStorageConfig": Dict[str, str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 StartDataCollectionByAgentIdsRequestRequestTypeDef = TypedDict(
     "StartDataCollectionByAgentIdsRequestRequestTypeDef",
     {
-        "agentIds": List[str],
-    },
-)
-
-StartDataCollectionByAgentIdsResponseTypeDef = TypedDict(
-    "StartDataCollectionByAgentIdsResponseTypeDef",
-    {
-        "agentsConfigurationStatus": List["AgentConfigurationStatusTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-StartExportTaskRequestRequestTypeDef = TypedDict(
-    "StartExportTaskRequestRequestTypeDef",
-    {
-        "exportDataFormat": List[ExportDataFormatType],
-        "filters": List["ExportFilterTypeDef"],
-        "startTime": Union[datetime, str],
-        "endTime": Union[datetime, str],
-    },
-    total=False,
-)
-
-StartExportTaskResponseTypeDef = TypedDict(
-    "StartExportTaskResponseTypeDef",
-    {
-        "exportId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "agentIds": Sequence[str],
     },
 )
 
@@ -720,14 +500,6 @@ class StartImportTaskRequestRequestTypeDef(
     pass
 
 
-StartImportTaskResponseTypeDef = TypedDict(
-    "StartImportTaskResponseTypeDef",
-    {
-        "task": "ImportTaskTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 StopContinuousExportRequestRequestTypeDef = TypedDict(
     "StopContinuousExportRequestRequestTypeDef",
     {
@@ -735,43 +507,10 @@ StopContinuousExportRequestRequestTypeDef = TypedDict(
     },
 )
 
-StopContinuousExportResponseTypeDef = TypedDict(
-    "StopContinuousExportResponseTypeDef",
-    {
-        "startTime": datetime,
-        "stopTime": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 StopDataCollectionByAgentIdsRequestRequestTypeDef = TypedDict(
     "StopDataCollectionByAgentIdsRequestRequestTypeDef",
     {
-        "agentIds": List[str],
-    },
-)
-
-StopDataCollectionByAgentIdsResponseTypeDef = TypedDict(
-    "StopDataCollectionByAgentIdsResponseTypeDef",
-    {
-        "agentsConfigurationStatus": List["AgentConfigurationStatusTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-TagFilterTypeDef = TypedDict(
-    "TagFilterTypeDef",
-    {
-        "name": str,
-        "values": List[str],
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "key": str,
-        "value": str,
+        "agentIds": Sequence[str],
     },
 )
 
@@ -795,3 +534,372 @@ class UpdateApplicationRequestRequestTypeDef(
     _RequiredUpdateApplicationRequestRequestTypeDef, _OptionalUpdateApplicationRequestRequestTypeDef
 ):
     pass
+
+
+AgentInfoTypeDef = TypedDict(
+    "AgentInfoTypeDef",
+    {
+        "agentId": str,
+        "hostName": str,
+        "agentNetworkInfoList": List[AgentNetworkInfoTypeDef],
+        "connectorId": str,
+        "version": str,
+        "health": AgentStatusType,
+        "lastHealthPingTime": str,
+        "collectionStatus": str,
+        "agentType": str,
+        "registeredTime": str,
+    },
+    total=False,
+)
+
+BatchDeleteImportDataResponseTypeDef = TypedDict(
+    "BatchDeleteImportDataResponseTypeDef",
+    {
+        "errors": List[BatchDeleteImportDataErrorTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateApplicationResponseTypeDef = TypedDict(
+    "CreateApplicationResponseTypeDef",
+    {
+        "configurationId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeConfigurationsResponseTypeDef = TypedDict(
+    "DescribeConfigurationsResponseTypeDef",
+    {
+        "configurations": List[Dict[str, str]],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ExportConfigurationsResponseTypeDef = TypedDict(
+    "ExportConfigurationsResponseTypeDef",
+    {
+        "exportId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListConfigurationsResponseTypeDef = TypedDict(
+    "ListConfigurationsResponseTypeDef",
+    {
+        "configurations": List[Dict[str, str]],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartContinuousExportResponseTypeDef = TypedDict(
+    "StartContinuousExportResponseTypeDef",
+    {
+        "exportId": str,
+        "s3Bucket": str,
+        "startTime": datetime,
+        "dataSource": Literal["AGENT"],
+        "schemaStorageConfig": Dict[str, str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartDataCollectionByAgentIdsResponseTypeDef = TypedDict(
+    "StartDataCollectionByAgentIdsResponseTypeDef",
+    {
+        "agentsConfigurationStatus": List[AgentConfigurationStatusTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartExportTaskResponseTypeDef = TypedDict(
+    "StartExportTaskResponseTypeDef",
+    {
+        "exportId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StopContinuousExportResponseTypeDef = TypedDict(
+    "StopContinuousExportResponseTypeDef",
+    {
+        "startTime": datetime,
+        "stopTime": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StopDataCollectionByAgentIdsResponseTypeDef = TypedDict(
+    "StopDataCollectionByAgentIdsResponseTypeDef",
+    {
+        "agentsConfigurationStatus": List[AgentConfigurationStatusTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeTagsResponseTypeDef = TypedDict(
+    "DescribeTagsResponseTypeDef",
+    {
+        "tags": List[ConfigurationTagTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeContinuousExportsResponseTypeDef = TypedDict(
+    "DescribeContinuousExportsResponseTypeDef",
+    {
+        "descriptions": List[ContinuousExportDescriptionTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateTagsRequestRequestTypeDef = TypedDict(
+    "CreateTagsRequestRequestTypeDef",
+    {
+        "configurationIds": Sequence[str],
+        "tags": Sequence[TagTypeDef],
+    },
+)
+
+_RequiredDeleteTagsRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteTagsRequestRequestTypeDef",
+    {
+        "configurationIds": Sequence[str],
+    },
+)
+_OptionalDeleteTagsRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteTagsRequestRequestTypeDef",
+    {
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class DeleteTagsRequestRequestTypeDef(
+    _RequiredDeleteTagsRequestRequestTypeDef, _OptionalDeleteTagsRequestRequestTypeDef
+):
+    pass
+
+
+GetDiscoverySummaryResponseTypeDef = TypedDict(
+    "GetDiscoverySummaryResponseTypeDef",
+    {
+        "servers": int,
+        "applications": int,
+        "serversMappedToApplications": int,
+        "serversMappedtoTags": int,
+        "agentSummary": CustomerAgentInfoTypeDef,
+        "connectorSummary": CustomerConnectorInfoTypeDef,
+        "meCollectorSummary": CustomerMeCollectorInfoTypeDef,
+        "agentlessCollectorSummary": CustomerAgentlessCollectorInfoTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAgentsRequestRequestTypeDef = TypedDict(
+    "DescribeAgentsRequestRequestTypeDef",
+    {
+        "agentIds": Sequence[str],
+        "filters": Sequence[FilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeAgentsRequestDescribeAgentsPaginateTypeDef = TypedDict(
+    "DescribeAgentsRequestDescribeAgentsPaginateTypeDef",
+    {
+        "agentIds": Sequence[str],
+        "filters": Sequence[FilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeContinuousExportsRequestDescribeContinuousExportsPaginateTypeDef = TypedDict(
+    "DescribeContinuousExportsRequestDescribeContinuousExportsPaginateTypeDef",
+    {
+        "exportIds": Sequence[str],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeExportConfigurationsRequestDescribeExportConfigurationsPaginateTypeDef = TypedDict(
+    "DescribeExportConfigurationsRequestDescribeExportConfigurationsPaginateTypeDef",
+    {
+        "exportIds": Sequence[str],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeExportConfigurationsResponseTypeDef = TypedDict(
+    "DescribeExportConfigurationsResponseTypeDef",
+    {
+        "exportsInfo": List[ExportInfoTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeExportTasksResponseTypeDef = TypedDict(
+    "DescribeExportTasksResponseTypeDef",
+    {
+        "exportsInfo": List[ExportInfoTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeExportTasksRequestDescribeExportTasksPaginateTypeDef = TypedDict(
+    "DescribeExportTasksRequestDescribeExportTasksPaginateTypeDef",
+    {
+        "exportIds": Sequence[str],
+        "filters": Sequence[ExportFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeExportTasksRequestRequestTypeDef = TypedDict(
+    "DescribeExportTasksRequestRequestTypeDef",
+    {
+        "exportIds": Sequence[str],
+        "filters": Sequence[ExportFilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+StartExportTaskRequestRequestTypeDef = TypedDict(
+    "StartExportTaskRequestRequestTypeDef",
+    {
+        "exportDataFormat": Sequence[ExportDataFormatType],
+        "filters": Sequence[ExportFilterTypeDef],
+        "startTime": Union[datetime, str],
+        "endTime": Union[datetime, str],
+    },
+    total=False,
+)
+
+DescribeImportTasksRequestRequestTypeDef = TypedDict(
+    "DescribeImportTasksRequestRequestTypeDef",
+    {
+        "filters": Sequence[ImportTaskFilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+DescribeImportTasksResponseTypeDef = TypedDict(
+    "DescribeImportTasksResponseTypeDef",
+    {
+        "nextToken": str,
+        "tasks": List[ImportTaskTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+StartImportTaskResponseTypeDef = TypedDict(
+    "StartImportTaskResponseTypeDef",
+    {
+        "task": ImportTaskTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeTagsRequestDescribeTagsPaginateTypeDef = TypedDict(
+    "DescribeTagsRequestDescribeTagsPaginateTypeDef",
+    {
+        "filters": Sequence[TagFilterTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeTagsRequestRequestTypeDef = TypedDict(
+    "DescribeTagsRequestRequestTypeDef",
+    {
+        "filters": Sequence[TagFilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+    },
+    total=False,
+)
+
+_RequiredListConfigurationsRequestListConfigurationsPaginateTypeDef = TypedDict(
+    "_RequiredListConfigurationsRequestListConfigurationsPaginateTypeDef",
+    {
+        "configurationType": ConfigurationItemTypeType,
+    },
+)
+_OptionalListConfigurationsRequestListConfigurationsPaginateTypeDef = TypedDict(
+    "_OptionalListConfigurationsRequestListConfigurationsPaginateTypeDef",
+    {
+        "filters": Sequence[FilterTypeDef],
+        "orderBy": Sequence[OrderByElementTypeDef],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListConfigurationsRequestListConfigurationsPaginateTypeDef(
+    _RequiredListConfigurationsRequestListConfigurationsPaginateTypeDef,
+    _OptionalListConfigurationsRequestListConfigurationsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListConfigurationsRequestRequestTypeDef = TypedDict(
+    "_RequiredListConfigurationsRequestRequestTypeDef",
+    {
+        "configurationType": ConfigurationItemTypeType,
+    },
+)
+_OptionalListConfigurationsRequestRequestTypeDef = TypedDict(
+    "_OptionalListConfigurationsRequestRequestTypeDef",
+    {
+        "filters": Sequence[FilterTypeDef],
+        "maxResults": int,
+        "nextToken": str,
+        "orderBy": Sequence[OrderByElementTypeDef],
+    },
+    total=False,
+)
+
+
+class ListConfigurationsRequestRequestTypeDef(
+    _RequiredListConfigurationsRequestRequestTypeDef,
+    _OptionalListConfigurationsRequestRequestTypeDef,
+):
+    pass
+
+
+ListServerNeighborsResponseTypeDef = TypedDict(
+    "ListServerNeighborsResponseTypeDef",
+    {
+        "neighbors": List[NeighborConnectionDetailTypeDef],
+        "nextToken": str,
+        "knownDependencyCount": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAgentsResponseTypeDef = TypedDict(
+    "DescribeAgentsResponseTypeDef",
+    {
+        "agentsInfo": List[AgentInfoTypeDef],
+        "nextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
